/*  Glimmer - highlightbar.h
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _HIGHLIGHTBAR_H_
#define _HIGHLIGHTBAR_H_

#ifdef __cplusplus
extern "C" {
#endif

#include "declarations.h"
#include "main.h"

void make_highlight_bar(GtkWidget *menu);

extern GtkWidget *highlightbar;
extern GtkWidget *rehighlight_button;
extern GtkWidget *reparse_button;
extern GtkWidget *highlightbar_option;

#ifdef __cplusplus
}
#endif

#endif
